# Sample Project
Quick Project to demonstrate Ellar's features

## Requirements
Python >= 3.7
Starlette
Injector

## Project setup
```
pip install poetry
```
then, 
```shell
poetry install
```

### Development Server
```
ellar runserver --reload
```

### Page
visit [http://127.0.0.1:8000/docs/](http://127.0.0.1:8000/docs/)
